@@ -1535,19 +1535,26 @@ class Nag
      */
     static public function _sortByDue($a, $b)
     {
-        if ($a->due == $b->due) {
-            return self::_sortByIdentity($a, $b);
+        $a_due = $a->getNextDue();
+        $b_due = $b->getNextDue();
+
+        if (!$a_due && !$b_due) {
+            return self::_sortByName($a, $b);
         }
 
         // Treat empty due dates as farthest into the future.
-        if ($a->due == 0) {
+        if (!$a_due) {
             return 1;
         }
-        if ($b->due == 0) {
+        if (!$b_due) {
             return -1;
         }
 
-        return ($a->due > $b->due) ? 1 : -1;
+        if ($a_due->equals($b_due)) {
+            return self::_sortByName($a, $b);
+        }
+
+        return ($a_due->after($b_due)) ? 1 : -1;
     }
 
     /**
